@@ -5,22 +5,14 @@ def whatsapp_loop_list(client, update: WhatsAppUpdate, context,  key, value, dop
         context[key] = []
 
     if value in context[key]:
-        client.messages.create(
-            body=doppelte_antwort,
-            from_=update.To,
-            to=update.From
-        )
+        client.send_message(doppelte_antwort, update.get_from())
         return "{}_FRAGE".format(key.upper())
     else:
         context[key].append(value)
 
 def whatsapp_loop_list_fertig(client, update: WhatsAppUpdate, context, key, answer_id_list, fertig_antwort):
     if set(answer_id_list).issubset(set(context[key])):
-        client.messages.create(
-            body=fertig_antwort,
-            from_=update.To,
-            to=update.From
-        )
+        client.send_message(fertig_antwort, update.get_from())
 
 def whatsapp_eval_list(client, update: WhatsAppUpdate, context, answer_id_name_list, poi, response_text):
     if not poi in context:
@@ -34,11 +26,7 @@ def whatsapp_eval_list(client, update: WhatsAppUpdate, context, answer_id_name_l
         else:
             response_text += "◽ {}\n".format(name)
 
-    client.messages.create(
-        body=response_text,
-        from_=update.To,
-        to=update.From
-    )
+    client.send_message(response_text, update.get_from())
 
 whatsapp_action_functions = {"loop_list": whatsapp_loop_list,
                              "eval_list": whatsapp_eval_list,
